"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Draw = /** @class */ (function () {
    function Draw() {
    }
    /**
     * Creates an instance of the element for the 'canvas' tag;
     * returns the instance
     *
     * @param canvasId
     * @param parentElement
     * @param options
     */
    Draw.createCanvas = function (canvasId, parentElement, options) {
        var canvasElement = document.createElement('canvas');
        canvasElement.id = canvasId;
        Object.keys(options).map(function (option) {
            canvasElement[option] = options[option];
        });
        parentElement.appendChild(canvasElement);
    };
    /**
     * Returns an object (includes information about colors, line widths, fonts,
     * and other graphic parameters that can be drawn on a canvas)
     * that provides methods and properties for drawing and manipulating
     * images and graphics on a canvas element in a document for the given canvas element id
     *
     * @param canvasId
     * @param contextType
     */
    Draw.getContextByCanvasId = function (canvasId, contextType) {
        if (contextType === void 0) { contextType = '2d'; }
        return document.getElementById(canvasId).getContext(contextType);
    };
    /**
     * Draws a circle of the given size and style at the given coordinates
     *
     * @param canvasId
     * @param dotX
     * @param dotY
     * @param radius
     * @param options
     */
    Draw.circle = function (canvasId, dotX, dotY, radius, options) {
        if (options === void 0) { options = {}; }
        var fillColor = options.fillColor, edgingWidth = options.edgingWidth, edgingColor = options.edgingColor;
        var ctx = document.getElementById(canvasId).getContext('2d');
        ctx.beginPath();
        ctx.arc(dotX, dotY, radius, 0, Math.PI * 2);
        if (fillColor) {
            ctx.fillStyle = fillColor;
            ctx.fill();
        }
        if (edgingWidth) {
            ctx.lineWidth = edgingWidth;
            ctx.strokeStyle = edgingColor;
            ctx.stroke();
        }
    };
    /**
     * Draws a circle sector of the given style at the given coordinates
     *
     * @param canvasId
     * @param dotX
     * @param dotY
     * @param radius
     * @param startAngle
     * @param endAngle
     * @param options
     */
    Draw.sector = function (canvasId, dotX, dotY, radius, startAngle, endAngle, options) {
        if (options === void 0) { options = {}; }
        var fillColor = options.fillColor, edgingWidth = options.edgingWidth, edgingColor = options.edgingColor;
        var ctx = document.getElementById(canvasId).getContext('2d');
        ctx.beginPath();
        ctx.moveTo(dotX, dotY);
        ctx.arc(dotX, dotY, radius, startAngle, endAngle);
        ctx.lineTo(dotX, dotY);
        ctx.closePath();
        if (fillColor) {
            ctx.fillStyle = fillColor;
            ctx.fill();
        }
        if (edgingWidth) {
            ctx.lineWidth = edgingWidth;
            ctx.strokeStyle = edgingColor;
            ctx.stroke();
        }
    };
    /**
     * Draws an arc of the given style at the given coordinates
     *
     * @param canvasId
     * @param cx
     * @param cy
     * @param radius
     * @param startAngle
     * @param endAngle
     * @param options
     */
    Draw.arc = function (canvasId, cx, cy, radius, startAngle, endAngle, options) {
        if (options === void 0) { options = {}; }
        var fillColor = options.fillColor, edgingWidth = options.edgingWidth, edgingColor = options.edgingColor;
        var ctx = document.getElementById(canvasId).getContext('2d');
        ctx.beginPath();
        ctx.arc(cx, cy, radius, startAngle, endAngle);
        if (fillColor) {
            ctx.fillStyle = fillColor;
            ctx.fill();
        }
        if (edgingWidth) {
            ctx.lineWidth = edgingWidth;
            ctx.strokeStyle = edgingColor;
            ctx.stroke();
        }
    };
    /**
     * Draws a line starting at the given coordinates of the given length at the given angle;
     * it returns an array of start and end positions of the line
     *
     * @param canvasId
     * @param x1
     * @param y1
     * @param length
     * @param angle
     * @param options
     */
    Draw.lineToAngle = function (canvasId, x1, y1, length, angle, options) {
        if (options === void 0) { options = {}; }
        var lineColor = options.lineColor, lineWidth = options.lineWidth;
        var ctx = document.getElementById(canvasId).getContext('2d');
        var a = angle * Math.PI / 180;
        var x2 = x1 + length * Math.cos(a);
        var y2 = y1 + length * Math.sin(a);
        if (lineWidth) {
            ctx.lineWidth = lineWidth;
            ctx.strokeStyle = lineColor;
            ctx.beginPath();
            ctx.moveTo(x1, y1);
            ctx.lineTo(x2, y2);
            ctx.stroke();
        }
        return [
            [x1, y1],
            [x2, y2],
        ];
    };
    /**
     * Draws a filled rectangle of the given size and style at the given coordinates
     *
     * @param canvasId
     * @param left
     * @param top
     * @param width
     * @param height
     * @param options
     */
    Draw.rectangle = function (canvasId, left, top, width, height, options) {
        if (options === void 0) { options = {}; }
        var fillColor = options.fillColor, edgingWidth = options.edgingWidth, edgingColor = options.edgingColor;
        var ctx = document.getElementById(canvasId).getContext('2d');
        if (fillColor) {
            ctx.fillStyle = fillColor;
            ctx.fillRect(left, top, width, height);
        }
        if (edgingWidth) {
            ctx.lineWidth = edgingWidth;
            ctx.strokeStyle = edgingColor;
            ctx.stroke();
        }
    };
    /**
     * Draws a filled triangle at the given coordinates
     *
     * @param canvasId
     * @param c1
     * @param c2
     * @param c3
     * @param options
     */
    Draw.triangle = function (canvasId, c1, c2, c3, options) {
        if (options === void 0) { options = {}; }
        var fillColor = options.fillColor, edgingWidth = options.edgingWidth, edgingColor = options.edgingColor;
        var ctx = document.getElementById(canvasId).getContext('2d');
        ctx.beginPath();
        ctx.moveTo(c1[0], c1[1]);
        ctx.lineTo(c2[0], c2[1]);
        ctx.lineTo(c3[0], c3[1]);
        ctx.closePath();
        if (fillColor) {
            ctx.fillStyle = fillColor;
            ctx.fill();
        }
        if (edgingWidth) {
            ctx.lineWidth = edgingWidth;
            ctx.strokeStyle = edgingColor;
            ctx.stroke();
        }
    };
    /**
     * Draws a star-like object with the given count of spikes at the given coordinates
     *
     * @param canvasId
     * @param cx
     * @param cy
     * @param spikes
     * @param outerRadius
     * @param innerRadius
     * @param options
     */
    Draw.star = function (canvasId, cx, cy, spikes, outerRadius, innerRadius, options) {
        if (options === void 0) { options = {}; }
        var fillColor = options.fillColor, edgingWidth = options.edgingWidth, edgingColor = options.edgingColor;
        var ctx = document.getElementById(canvasId).getContext('2d');
        var step = Math.PI / spikes;
        var rotation = Math.PI / 2 * 3;
        var x = cx;
        var y = cy;
        ctx.beginPath();
        ctx.moveTo(cx, cy - outerRadius);
        for (var i = 0; i < spikes; i += 1) {
            x = cx + Math.cos(rotation) * outerRadius;
            y = cy + Math.sin(rotation) * outerRadius;
            ctx.lineTo(x, y);
            rotation += step;
            x = cx + Math.cos(rotation) * innerRadius;
            y = cy + Math.sin(rotation) * innerRadius;
            ctx.lineTo(x, y);
            rotation += step;
        }
        ctx.lineTo(cx, cy - outerRadius);
        ctx.closePath();
        if (edgingWidth) {
            ctx.lineWidth = edgingWidth;
            ctx.strokeStyle = edgingColor;
            ctx.stroke();
        }
        if (fillColor) {
            ctx.fillStyle = fillColor;
            ctx.fill();
        }
    };
    return Draw;
}());
exports.Draw = Draw;
//# sourceMappingURL=Draw.js.map