"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Maths = /** @class */ (function () {
    function Maths() {
    }
    /**
     * Returns true if one line segment intersects with another
     *
     * @param segment1
     * @param segment2
     */
    Maths.lineSegmentsIntersect = function (segment1, segment2) {
        var det = (segment1.end.x - segment1.start.x) * (segment2.end.y - segment2.start.y) -
            (segment2.end.x - segment2.start.x) * (segment1.end.y - segment1.start.y);
        if (det === 0) {
            return false;
        }
        var lambda = ((segment2.end.y - segment2.start.y) * (segment2.end.x - segment1.start.x) +
            (segment2.start.x - segment2.end.x) * (segment2.end.y - segment1.start.y)) / det;
        var gamma = ((segment1.start.y - segment1.end.y) * (segment2.end.x - segment1.start.x) +
            (segment1.end.x - segment1.start.x) * (segment2.end.y - segment1.start.y)) / det;
        return (lambda > 0 && lambda < 1) && (gamma > 0 && gamma < 1);
    };
    /**
     * Checks if a point belongs to a line segment
     *
     * @param segment
     * @param point
     * @param tolerance
     */
    Maths.pointOnLineSegment = function (segment, point, tolerance) {
        var dxL = segment.end.x - segment.start.x;
        var dyL = segment.end.y - segment.start.y;
        var dxP = point.x - segment.start.x;
        var dyP = point.y - segment.start.y;
        var squareLen = dxL * dxL + dyL * dyL;
        var dotProd = dxP * dxL + dyP * dyL;
        var crossProd = dyP * dxL - dxP * dyL;
        return (Math.abs(crossProd) / Math.sqrt(squareLen) <= tolerance && dotProd >= 0 && dotProd <= squareLen);
    };
    /**
     * Checks if a line segment intersects with a rectangle by checking intersection
     * with each of its sides; returns true if at least one intersection registered
     *
     * @param segment
     * @param rectCoords
     */
    Maths.lineSegmentIntersectsWithRect = function (segment, rectCoords) {
        var segment1 = {
            start: { x: rectCoords[0], y: rectCoords[1] },
            end: { x: rectCoords[2], y: rectCoords[1] },
        };
        var segment2 = {
            start: { x: rectCoords[0], y: rectCoords[1] },
            end: { x: rectCoords[0], y: rectCoords[3] },
        };
        var segment3 = {
            start: { x: rectCoords[0], y: rectCoords[3] },
            end: { x: rectCoords[2], y: rectCoords[3] },
        };
        var segment4 = {
            start: { x: rectCoords[2], y: rectCoords[1] },
            end: { x: rectCoords[2], y: rectCoords[3] },
        };
        return (this.lineSegmentsIntersect(segment, segment1)
            || this.lineSegmentsIntersect(segment, segment2)
            || this.lineSegmentsIntersect(segment, segment3)
            || this.lineSegmentsIntersect(segment, segment4));
    };
    return Maths;
}());
exports.Maths = Maths;
//# sourceMappingURL=Maths.js.map